from urllib.parse import urlencode

from fast_query_parsers import parse_url_encoded_dict


def test_parse_urlencoded_with_parse_numbers() -> None:
    encoded = urlencode(
        [
            ("value", "10"),
            ("value", "12"),
            ("veggies", '["tomato", "potato", "aubergine"]'),
            ("nested", '{"some_key": "some_value"}'),
            ("calories", "122.53"),
            ("healthy", "true"),
            ("polluting", "false"),
            ("json", "null"),
        ],
    ).encode()
    result = parse_url_encoded_dict(encoded, True)
    assert result == {
        "value": [10, 12],
        "veggies": ["tomato", "potato", "aubergine"],
        "nested": {"some_key": "some_value"},
        "calories": 122.53,
        "healthy": True,
        "polluting": False,
        "json": None,
    }


def test_parse_urlencoded_without_parse_numbers() -> None:
    encoded = urlencode(
        [
            ("value", "10"),
            ("value", "12"),
            ("veggies", '["tomato", "potato", "aubergine"]'),
            ("nested", '{"some_key": "some_value"}'),
            ("calories", "122.53"),
            ("healthy", "true"),
            ("polluting", "false"),
            ("json", "null"),
        ],
    ).encode()
    result = parse_url_encoded_dict(encoded, False)
    assert result == {
        "value": ["10", "12"],
        "veggies": ["tomato", "potato", "aubergine"],
        "nested": {"some_key": "some_value"},
        "calories": "122.53",
        "healthy": True,
        "polluting": False,
        "json": None,
    }



from typing import Any

def parse_query_string(qs: bytes, separator: str) -> list[tuple[str, str]]: ...

"""Parse a query string into a list of tuples.

Args:
    qs: a query byte-string.
    separator: A separator symbol.

Returns:
    A list of string/string tuples.
"""

def parse_url_encoded_dict(qs: bytes, parse_numbers: bool) -> dict[str, Any]: ...

"""Parse a query string into a dictionary of values.

Args:
    qs: a query byte-string.
    parse_numbers: If true, parse numbers into ints and floats otherwise keep them as strings.

Returns:
    A string keyed dictionary of parsed values.
"""

__all__ = ("parse_query_string", "parse_url_encoded_dict")
